#       tar.bash
#       This file is part of zenpakt

#       Copyright 2010 Anshul Narula aka sunny <sunny_delhi18@yahoo.com>
#
#       Zenpakt is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 2 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program; if not, write to the Free Software
#       Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#       MA 02110-1301, USA.

$DOC
=====
 tar
=====

-----------------------------------
 check for tar and call actual tar
-----------------------------------

SYNOPSIS
========

tar tar_options file

DESCRIPTION
===========

the first call to this function resets the function definition accordingly so that
the next call calls the new function and there is no need for check every time
the function is called.
use $TAR as a command if set or also check for tar and set $TAR and make $TAR
readonly for future calls.
The first call without any arguments, serves to check for existence of tar, searched
in the order of preference of TAR, tar-1.13 and tar(replacement for earlier tar -c).
If you want to call the normal command tar, use `command tar` (replacement for tar -t)

$ENDDOC

$$

#This variable if in environment is used to supply extra command line options to
#tar, we unset it to be sure nothing we do not expect is passed to tar
#e.g --verbose passed to tar may interfere with the way we store files list in
#database during install
unset TAR_OPTIONS

tar() {

  #if $TAR is set an non null
  if [[ $TAR ]] && hash "$TAR" 2>/dev/null; then
    tar() { command "$TAR" "$@" ;}
    readonly TAR

  #if tar-1.13 is an executable
  elif hash tar-1.13 2>/dev/null; then
    tar() { command tar-1.13 "$@" ;}

  #if all else fails check for tar itself
  elif hash tar 2>/dev/null; then
    tar() { command tar "$@" ;}
    warn_v "using tar instead of tar-1.13" >&2
  #if that fails too
  else
    tar() { return 1 ;}
    return 1
  fi

  #If we reached here, we found at least one of the tar; if the function was called
  #without any arguments, it was meant as a preliminary check for existence of tar; if we
  #didn't find any, we would already have had returned one; and if we are here we should
  #return 0
  (($#)) || return 0
  #If we were called with arguments, we need to call the function and return its status
  #the caller doesnot care about the existence of tar or does not want to differentiate
  #between existence and error while executing the function
  tar "$@"
}
